@@ -1,5 +1,5 @@
 #
-# $Id: Jcode.pm,v 2.5 2006/05/16 05:00:19 dankogai Exp dankogai $
+# $Id: Jcode.pm,v 2.6 2006/07/02 07:56:06 dankogai Exp dankogai $
 #
 
 package Jcode;
@@ -8,8 +8,8 @@ use Carp;
 use strict;
 use vars qw($RCSID $VERSION $DEBUG);
 
-$RCSID = q$Id: Jcode.pm,v 2.5 2006/05/16 05:00:19 dankogai Exp dankogai $;
-$VERSION = do { my @r = (q$Revision: 2.5 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$RCSID = q$Id: Jcode.pm,v 2.6 2006/07/02 07:56:06 dankogai Exp dankogai $;
+$VERSION = do { my @r = (q$Revision: 2.6 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $DEBUG = 0;
 
 # we no longer use Exporter
@@ -320,6 +320,7 @@ sub tr{
     my $opt  = $_[2] || '';
     $from =~ s,\\,\\\\,og; $from =~ s,/,\\/,og;
     $to   =~ s,\\,\\\\,og; $to   =~ s,/,\\/,og;
+    $opt  =~ s,[^a-z],,og;
     my $match = eval qq{ \$str =~ tr/$from/$to/$opt };
     if ($@){
         $self->{error_tr} = $@;
@@ -508,6 +509,9 @@ sub m{
     my $pattern = Encode::is_utf8($_[0]) ? shift : decode("euc-jp" => shift);
     my $opt     = shift || '' ;
     my @match;
+
+    $pattern =~ s,\\,\\\\,og; $pattern =~ s,/,\\/,og;
+    $opt     =~ s,[^a-z],,og;
     
     eval qq{ \@match = (\$\$r_str =~ m/$pattern/$opt) };
     if ($@){
@@ -525,6 +529,11 @@ sub s{
     my $pattern = Encode::is_utf8($_[0]) ? shift : decode("euc-jp" => shift);
     my $replace = Encode::is_utf8($_[0]) ? shift : decode("euc-jp" => shift);
     my $opt     = shift;
+
+    $pattern =~ s,\\,\\\\,og; $pattern =~ s,/,\\/,og;
+    $replace =~ s,\\,\\\\,og; $replace =~ s,/,\\/,og;
+    $opt     =~ s,[^a-z],,og;
+
     eval qq{ (\$\$r_str =~ s/$pattern/$replace/$opt) };
     if ($@){
 	$self->{error_s} = $@;
